@@ -108,14 +108,14 @@ sub geo_property {
   my %properties = @_;
 
   # Add all available properties
-  foreach my $tag (grep(/^(?:(?:relationship|featuretype)tag|featurename)$/i,
+  foreach my $tag (grep(/^(?:(?:relationship|featureType)Tag|featureName)$/,
 		keys %properties)) {
 
     my $val = $properties{$tag};
 
     # Add as an array, if it is one
     foreach (ref $val ? @$val : ($val)) {
-      $self->add( lc($tag) => $_ );
+      $self->add($tag => $_);
     };
   };
 
@@ -129,9 +129,9 @@ sub geo_floor {
 };
 
 
-# Add 'elev' element
-sub geo_elev {
-  shift->add(elev => shift);
+# Add 'even' element
+sub geo_even {
+  shift->add(even => shift);
 };
 
 
@@ -211,8 +211,6 @@ XML::Loy::GeoRSS - GeoRSS (Simple) Format Extension
 
 =head1 SYNOPSIS
 
-  use XML::Loy::Atom;
-
   my $atom = XML::Loy::Atom->new('entry');
   $atom->extension(-GeoRSS);
 
@@ -226,8 +224,8 @@ XML::Loy::GeoRSS - GeoRSS (Simple) Format Extension
 
 L<XML::Loy::GeoRSS> is an extension
 for L<XML::Loy> base classes and provides addititional
-functions for the work with geographic location as described in the
-L<specification|http://georss.org/simple>.
+functions for the work with geographic location as described in
+L<http://georss.org/simple|Specification>.
 This represents the simple variant rather than the GML flavour.
 
 B<This module is an early release! There may be significant changes in the future.>
@@ -271,11 +269,11 @@ Add C<circle> element based on one coordinate
 and a value for radius, or get circle.
 
 
-=head2 C<geo_elev>
+=head2 C<geo_even>
 
-  $atom->geo_elev(40);
+  $atom->geo_even(40);
 
-Add C<elev> element.
+Add C<even> element.
 
 
 =head2 C<geo_floor>
@@ -309,7 +307,7 @@ or get coordinates.
   # 4.56
 
 Add C<point> element based on one coordinate,
-or get it.
+or get them.
 
 
 =head2 C<geo_polygon>
@@ -326,12 +324,12 @@ or get coordinates.
 =head2 C<geo_property>
 
   $atom->geo_property(
-    relationshiptag => 'test',
-    featuretypetag  => [qw/foo bar/]
+    relationshipTag => 'test',
+    featureTypeTag  => [qw/foo bar/]
   );
 
-Add geo features by means of C<relationshiptag>,
-C<featuretypetag> or C<featurename> element.
+Add geo features by means of C<relationshipTag>, C<featureTypeTag> or
+C<featureName> element.
 
 =head2 C<geo_radius>
 
@@ -359,7 +357,7 @@ L<Mojolicious>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2016, Nils Diewald.
+Copyright (C) 2011-2013, Nils Diewald.
 
 This program is free software, you can redistribute it
 and/or modify it under the same terms as Perl.
